=========
ChangeLog
=========


v0.3.4
======

* Added support for alternate specification of job execution via
  `scheduler.delegator` config


v0.3.3
======

* Improved "async" jobs to run immediately instead of relying on
  APScheduler (thus improving time-to-execution)


v0.3.2
======

* Removed `distribute` dependency


v0.3.1
======

* Fix for Python 3 support
  (thanks to github.com/farvour -- issue #7)


v0.3.0
======

* Added Python 3 support
  (thanks to github.com/farvour -- issue #3)
* Implemented workaround for kombu (python3 + pickle + bzip2) issue


v0.2.5
======

* Added ultra-basic unit test
* Fixed serializer to work with kombu 3.0.8
  (thanks to github.com/mazvv -- issue #2)


v0.2.4
======

* First tagged release
